<?php $TRANSLATIONS = array(
"Timezone changed" => "အချိန်ဇုံပြောင်းလဲသည်",
"Invalid request" => "တောင်းဆိုချက်မမှန်ကန်ပါ",
"Calendar" => "ပြက္ခဒိန်",
"can edit" => "ပြင်ဆင်နိုင်",
"January" => "ဇန်နဝါရီ",
"February" => "ဖေဖော်ဝါရီ",
"March" => "မတ်",
"April" => "ဧပြီ",
"May" => "မေ",
"June" => "ဇွန်",
"July" => "ဇူလိုင်",
"August" => "ဩဂုတ်",
"September" => "စက်တင်ဘာ",
"October" => "အောက်တိုဘာ",
"November" => "နိုဝင်ဘာ",
"December" => "ဒီဇင်ဘာ",
"All day" => "နေ့တိုင်း",
"Title" => "ခေါင်းစဉ်",
"Daily" => "နေ့တိုင်း",
"Weekly" => "အပတ်တိုင်း",
"Week" => "အပတ်",
"Month" => "လ",
"Today" => "ယနေ့",
"Download" => "ဒေါင်းလုတ်",
"Edit calendar" => "ပြက္ခဒိန်ကိုပြင်မည်",
"Title of the Event" => "ပွဲ၏ခေါင်းစဉ်",
"Location" => "တည်နေရာ",
"Description" => "ဖော်ပြချက်",
"Advanced" => "အဆင့်မြင့်",
"Create a new event" => "ပွဲအသစ်တစ်ပွဲပြုလုပ်မည်",
"From" => "မှ",
"To" => "သို့"
);
